@@ -4,6 +4,8 @@ Parent classes for all families.
 # pylint: disable=no-member
 from collections import namedtuple
 
+from ipywidgets import interact
+import ipywidgets as ipyw
 import numpy as np
 
 from ..utils.plot_utils import plot_pdfpmf, plot_cdf, plot_ppf
@@ -26,14 +28,8 @@ class Distribution:
         if self.is_frozen:
             bolded_name = "\033[1m" + self.name.capitalize() + "\033[0m"
 
-            # temporary patch until we migrate all distributions to use
-            # self.params_report and self.params
-            try:
-                params_value = self.params_report
-            except AttributeError:
-                params_value = self.params
             description = "".join(
-                f"{n}={v:.2f}," for n, v in zip(self.param_names, params_value)
+                f"{n}={v:.2f}," for n, v in zip(self.param_names, self.params)
             ).strip(",")
             return f"{bolded_name}({description})"
         else:
@@ -73,7 +69,7 @@ class Distribution:
         else:
             return None
 
-    def rvs(self, size=1, random_state=None):
+    def rvs(self, *args, **kwds):
         """Random sample
 
         Parameters
@@ -83,7 +79,27 @@ class Distribution:
         random_state : {None, int, numpy.random.Generator, numpy.random.RandomState}
             Defaults to None
         """
-        return self.rv_frozen.rvs(size=size, random_state=random_state)
+        return self.rv_frozen.rvs(*args, **kwds)
+
+    def cdf(self, x, *args, **kwds):
+        """Cumulative distribution function.
+
+        Parameters
+        ----------
+        x : array_like
+            Values on which to evaluate the cdf
+        """
+        return self.rv_frozen.cdf(x, *args, **kwds)
+
+    def ppf(self, q, *args, **kwds):
+        """Percent point function (inverse of cdf).
+
+        Parameters
+        ----------
+        x : array_like
+            Values on which to evaluate the inverse of the cdf
+        """
+        return self.rv_frozen.ppf(q, *args, **kwds)
 
     def eti(self, fmt=".2f", mass=0.94):
         """Equal-tailed interval containing `mass`.
@@ -171,9 +187,9 @@ class Distribution:
             lower_ep, upper_ep = self.support
 
             if not np.isfinite(lower_ep) or support == "restricted":
-                lower_ep = self.rv_frozen.ppf(0.0001)
+                lower_ep = self.ppf(0.0001)
             if not np.isfinite(upper_ep) or support == "restricted":
-                upper_ep = self.rv_frozen.ppf(0.9999)
+                upper_ep = self.ppf(0.9999)
 
         return lower_ep, upper_ep
 
@@ -208,7 +224,7 @@ class Distribution:
             end-points or if ``restricted`` use the 0.001 and 0.999 quantiles to set the limits.
         legend : str
             Whether to include a string with the distribution and its parameter as a ``"legend"`` a
-            ``"title"`` or not include them ``None``.
+            ``"title"`` or not include them ``False``.
         figsize : tuple
             Size of the figure
         ax : matplotlib axes
@@ -254,7 +270,7 @@ class Distribution:
             end-points or if ``restricted`` use the 0.001 and 0.999 quantiles to set the limits.
         legend : str
             Whether to include a string with the distribution and its parameter as a ``"legend"`` a
-            ``"title"`` or not include them ``None``.
+            ``"title"`` or not include them ``False``.
         figsize : tuple
             Size of the figure
         ax : matplotlib axes
@@ -294,7 +310,7 @@ class Distribution:
             should be 5, 3, 1 or 0 (in this last case nothing will be plotted).
         legend : str
             Whether to include a string with the distribution and its parameter as a ``"legend"`` a
-            ``"title"`` or not include them ``None``.
+            ``"title"`` or not include them ``False``.
         figsize : tuple
             Size of the figure
         ax : matplotlib axes
@@ -307,6 +323,80 @@ class Distribution:
                 "you need to first define its parameters or use one of the fit methods"
             )
 
+    def plot_interactive(self, kind="pdf", fixed_lim="both", pointinterval=True, quantiles=None):
+        """
+        Interactive exploration of distributions parameters
+
+        Parameters
+        ----------
+        kind : str:
+            Type of plot. Available options are `pdf`, `cdf` and `ppf`.
+        fixed_lim : str or tuple
+            Set the limits of the x-axis and/or y-axis.
+            Defaults to `"both"`, the limits of both axis are fixed.
+            Use `"auto"` for automatic rescaling of x-axis and y-axis.
+            Or set them manually by passing a tuple of 4 elements,
+            the first two fox x-axis, the last two for x-axis. The tuple can have `None`.
+        pointinterval : bool
+            Whether to include a plot of the quantiles. Defaults to False. If True the default is to
+            plot the median and two interquantiles ranges.
+        quantiles : list
+            Values of the five quantiles to use when ``pointinterval=True`` if None (default)
+            the values ``[0.05, 0.25, 0.5, 0.75, 0.95]`` will be used. The number of elements
+            should be 5, 3, 1 or 0 (in this last case nothing will be plotted).
+        """
+        args = dict(zip(self.param_names, self.params))
+
+        if fixed_lim == "both":
+            self.__init__(**args)
+            xlim = self._finite_endpoints("full")
+            xvals = self.xvals("restricted")
+            ylim = (0, np.max(self.pdf(xvals) * 1.5))
+        elif isinstance(fixed_lim, tuple):
+            xlim = fixed_lim[:2]
+            ylim = fixed_lim[2:]
+
+        sliders = {}
+        for name, value, support in zip(self.param_names, self.params, self.params_support):
+            lower, upper = support
+            if np.isfinite(lower):
+                min_v = lower
+            else:
+                min_v = value - 10
+            if np.isfinite(upper):
+                max_v = upper
+            else:
+                max_v = value + 10
+
+            if isinstance(value, float):
+                slider_type = ipyw.FloatSlider
+                step = (max_v - min_v) / 100
+            else:
+                slider_type = ipyw.FloatSlider
+                step = 1
+            sliders[name] = slider_type(
+                min=min_v,
+                max=max_v,
+                step=step,
+                description=f"{name} ({lower:.0f}, {upper:.0f})",
+                value=value,
+            )
+
+        def plot(**args):
+            self.__init__(**args)
+            if kind == "pdf":
+                ax = self.plot_pdf(legend=False, pointinterval=pointinterval, quantiles=quantiles)
+            elif kind == "cdf":
+                ax = self.plot_cdf(legend=False, pointinterval=pointinterval, quantiles=quantiles)
+            elif kind == "ppf":
+                ax = self.plot_ppf(legend=False, pointinterval=pointinterval, quantiles=quantiles)
+            if fixed_lim != "auto" and kind != "ppf":
+                ax.set_xlim(*xlim)
+            if fixed_lim != "auto" and kind != "cdf":
+                ax.set_ylim(*ylim)
+
+        interact(plot, **sliders)
+
 
 class Continuous(Distribution):
     """Base class for continuous distributions."""
@@ -341,6 +431,16 @@ class Continuous(Distribution):
         """
         raise NotImplementedError
 
+    def pdf(self, x, *args, **kwds):
+        """Probability density function at x.
+
+        Parameters
+        ----------
+        x : array_like
+            Values on which to evaluate the pdf
+        """
+        return self.rv_frozen.pdf(x, *args, **kwds)
+
 
 class Discrete(Distribution):
     """Base class for discrete distributions."""
@@ -356,3 +456,13 @@ class Discrete(Distribution):
         lower_ep, upper_ep = self._finite_endpoints(support)
         x_vals = np.arange(lower_ep, upper_ep + 1, dtype=int)
         return x_vals
+
+    def pdf(self, x, *args, **kwds):
+        """Probability mass function at x.
+
+        Parameters
+        ----------
+        x : array_like
+            Values on which to evaluate the pdf
+        """
+        return self.rv_frozen.pmf(x, *args, **kwds)
